@@ -131,10 +131,10 @@ class Grilo(GObject.GObject):
                     media_id = media.get_id()
                     if changeType == Grl.SourceChangeType.ADDED:
                         # Check that this media is an audio file
-                        mime_type = grilo.tracker.query_sync(
+                        mime_type = self.tracker.query_sync(
                             Query.is_audio(media_id),
                             [Grl.METADATA_KEY_MIME],
-                            grilo.options)[0].get_mime()
+                            self.options)[0].get_mime()
                         if mime_type and mime_type.startswith("audio"):
                             self.changed_media_ids.append(media_id)
                     if changeType == Grl.SourceChangeType.REMOVED:
@@ -232,24 +232,33 @@ class Grilo(GObject.GObject):
 
     @log
     def populate_artists(self, offset, callback, count=-1):
-        self.populate_items(Query.all_artists(), offset, callback, count)
+        if self.tracker:
+            GLib.idle_add(self.populate_items, Query.all_artists(), offset,
+                          callback, count)
 
     @log
     def populate_albums(self, offset, callback, count=-1):
-        self.populate_items(Query.all_albums(), offset, callback, count)
+        if self.tracker:
+            GLib.idle_add(self.populate_items, Query.all_albums(), offset,
+                                                callback, count)
 
     @log
     def populate_songs(self, offset, callback, count=-1):
-        self.populate_items(Query.all_songs(), offset, callback, count)
+        if self.tracker:
+            GLib.idle_add(self.populate_items, Query.all_songs(), offset,
+                                                callback, count)
 
     @log
     def populate_playlists(self, offset, callback, count=-1):
-        self.populate_items(Query.all_playlists(), offset, callback, count)
+        if self.tracker:
+            GLib.idle_add(self.populate_items, Query.all_playlists(), offset,
+                                                callback, count)
 
     @log
     def populate_album_songs(self, album, callback, count=-1):
         if album.get_source() == 'grl-tracker-source':
-            self.populate_items(Query.album_songs(album.get_id()), 0, callback, count)
+            GLib.idle_add(self.populate_items,
+                          Query.album_songs(album.get_id()), 0, callback, count)
         else:
             source = self.sources[album.get_source()]
             length = len(album.tracks)
@@ -259,7 +268,10 @@ class Grilo(GObject.GObject):
 
     @log
     def populate_playlist_songs(self, playlist, callback, count=-1):
-        self.populate_items(Query.playlist_songs(playlist.get_id()), 0, callback, count)
+        if self.tracker:
+            GLib.idle_add(self.populate_items,
+                          Query.playlist_songs(playlist.get_id()), 0, callback,
+                          count)
 
     @log
     def populate_custom_query(self, query, callback, count=-1, data=None):
