@@ -62,6 +62,7 @@ class BaseManager:
                 ['search_all', _("All"), ''],
                 ['search_artist', _("Artist"), ''],
                 ['search_album', _("Album"), ''],
+                ['search_composer', _("Composer"), ''],
                 ['search_track', _("Track Title"), ''],
             ]
         for value in self.values:
@@ -284,6 +285,7 @@ class Searchbar(Gtk.SearchBar):
     @log
     def _search_entry_tag_button_clicked(self, entry, tag):
         tag.manager.set_active(tag.manager.values[1][BaseModelColumns.ID])
+        self.search_entry_changed(None)
 
     @log
     def search_entry_timeout(self, widget):
