@@ -162,6 +162,8 @@ class BaseView(Gtk.Stack):
 
     @log
     def _on_grilo_ready(self, data=None):
+        # FIXME: with async changes in Window this seems never to be
+        # called anymore. Fix it proper or remove.
         if (self.header_bar.get_stack().get_visible_child() == self and not self._init):
             self._populate()
         self.header_bar.get_stack().connect('notify::visible-child',
@@ -203,7 +205,7 @@ class BaseView(Gtk.Stack):
 
     @log
     def populate(self):
-        print('populate')
+        pass
 
     @log
     def _add_item(self, source, param, item, remaining=0, data=None):
@@ -264,9 +266,6 @@ class BaseView(Gtk.Stack):
     def get_selected_tracks(self, callback):
         callback([])
 
-    def _on_list_widget_star_render(self, col, cell, model, _iter, data):
-        pass
-
     @log
     def _set_selection(self, value, parent=None):
         count = 0
