@@ -198,9 +198,6 @@ class PlaylistView(BaseView):
     def _on_list_widget_title_render(self, col, cell, model, _iter, data):
         pass
 
-    def _on_list_widget_star_render(self, col, cell, model, _iter, data):
-        pass
-
     def _on_list_widget_duration_render(self, col, cell, model, _iter, data):
         if not model.iter_is_valid(_iter):
             return
@@ -221,7 +218,7 @@ class PlaylistView(BaseView):
 
         item = model.get_value(_iter, 5)
         if item:
-            cell.set_property('text', item.get_album() or _("Unknown Album"))
+            cell.set_property('text', utils.get_album_title(item))
 
     def _on_list_widget_icon_render(self, col, cell, model, _iter, data):
         if not self.player.currentTrackUri:
@@ -374,7 +371,7 @@ class PlaylistView(BaseView):
         self.view.set_model(None)
         self.model.clear()
         self.songs_count = 0
-        GLib.idle_add(grilo.populate_playlist_songs, playlist, self._add_item)
+        grilo.populate_playlist_songs(playlist, self._add_item)
 
         # disable delete button if current playlist is a smart playlist
         if self.current_playlist_is_protected():
@@ -399,7 +396,7 @@ class PlaylistView(BaseView):
         self._offset += 1
         title = utils.get_media_title(item)
         item.set_title(title)
-        artist = item.get_artist() or _("Unknown Artist")
+        artist = utils.get_album_title(item)
         model.insert_with_valuesv(
             -1,
             [2, 3, 5, 9],
@@ -524,10 +521,8 @@ class PlaylistView(BaseView):
 
     @log
     def populate(self):
-        if grilo.tracker:
-            self.playlists_model.clear()
-            GLib.idle_add(grilo.populate_playlists, self._offset,
-                          self._add_playlist_item)
+        self.playlists_model.clear()
+        grilo.populate_playlists(self._offset, self._add_playlist_item)
 
     @log
     def get_selected_tracks(self, callback):
